@@ -12,7 +12,12 @@ pub enum ExecuteMsg {
         name: String,
         receiver: String,
         swap_address: String,
-        token1_amount: Uint128,
+        token2_amount: Uint128,
         type_code: String
     }
 }
+
+#[derive(Serialize, Deserialize, Clone, Debug, JsonSchema)]
+pub struct MigrateMsg {
+    pub admin: String
+}
\ No newline at end of file
