@@ -5,10 +5,20 @@ use cosmwasm_std::{Uint128};
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct SwapDetailsResponse {
+    pub name: String,
+    pub receiver: String,
+    pub swap_address: String,
+    pub token2_amount: Uint128,
+    pub type_code: String
+}
+
+#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
+pub struct SwapDetailsPriceResponse {
     pub name: String,
     pub receiver: String,
     pub swap_address: String,
     pub token1_amount: Uint128,
+    pub token2_amount: Uint128,
     pub type_code: String
 }
 
