@@ -1,8 +1,8 @@
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-use cosmwasm_std::{StdResult, Uint128};
-use cw_storage_plus::{Map};
+use cosmwasm_std::{Addr, StdResult, Uint128};
+use cw_storage_plus::{Item, Map};
 use crate::query::SwapDetailsResponse;
 
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
@@ -10,7 +10,7 @@ pub struct SwapDetails {
     pub name: String,
     pub receiver: String,
     pub swap_address: String,
-    pub token1_amount: Uint128,
+    pub token2_amount: Uint128,
     pub type_code: String
 }
 
@@ -21,10 +21,16 @@ impl SwapDetails {
             name: swap_details.name,
             receiver: swap_details.receiver,
             swap_address: swap_details.swap_address,
-            token1_amount: swap_details.token1_amount,
+            token2_amount: swap_details.token2_amount,
             type_code: swap_details.type_code,
         })
     }
 }
 
+#[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
+pub struct Admin {
+    pub address: Addr
+}
+
 pub const SWAP_DETAILS: Map<&str, SwapDetails> = Map::new("swap_details");
+pub const ADMIN: Item<Admin> = Item::new("admin");
