@@ -1,8 +1,8 @@
 use cosmwasm_std::{BankMsg, Coin, CosmosMsg, Deps, MessageInfo, QueryRequest, Response, StdError, StdResult, SubMsg, to_binary, Uint128, WasmQuery};
-use wasmswap::msg::Token1ForToken2PriceResponse;
+use wasmswap::msg::{Token2ForToken1PriceResponse};
 use crate::{query};
 use crate::error::PaymentError;
-use crate::query::SwapDetailsResponse;
+use crate::query::{SwapDetailsPriceResponse, SwapDetailsResponse};
 
 pub fn coin_amount(info: &MessageInfo, amount: Uint128) -> Result<Coin, PaymentError> {
     match info.funds.len() {
@@ -44,30 +44,30 @@ pub fn send_payment(sender: String, receiver: String, coin: Vec<Coin>) -> Respon
 pub fn query_contract_price(
     deps: Deps,
     contract_addr: String,
-    token1_amount: Uint128
-) -> StdResult<Token1ForToken2PriceResponse> {
-    let mut token2: Token1ForToken2PriceResponse = deps.querier
+    token2_amount: Uint128
+) -> StdResult<Token2ForToken1PriceResponse> {
+    let mut token1: Token2ForToken1PriceResponse = deps.querier
         .query(&QueryRequest::Wasm(WasmQuery::Smart {
             contract_addr,
-            msg: to_binary(&wasmswap::msg::QueryMsg::Token1ForToken2Price {
-                token1_amount
+            msg: to_binary(&wasmswap::msg::QueryMsg::Token2ForToken1Price {
+                token2_amount
             })?,
         }))?;
 
-    token2.token2_amount = token2.token2_amount
+    token1.token1_amount = token1.token1_amount
         .checked_div(Uint128::new(97))
         .map_err(StdError::divide_by_zero)?
         .checked_mul(Uint128::new(100))// LP Fees
         .map_err(StdError::overflow)?;
 
-    Ok(token2)
+    Ok(token1)
 }
 
 pub fn query_code_price(
     deps: Deps,
     contract_addr: String,
     type_code: String
-) -> StdResult<SwapDetailsResponse> {
+) -> StdResult<SwapDetailsPriceResponse> {
     let details: SwapDetailsResponse = deps.querier
         .query(&QueryRequest::Wasm(WasmQuery::Smart {
             contract_addr,
@@ -75,16 +75,17 @@ pub fn query_code_price(
                 type_code: type_code.clone()
             })?,
         }))?;
-    let price: Token1ForToken2PriceResponse = query_contract_price(
+    let price: Token2ForToken1PriceResponse = query_contract_price(
         deps,
         details.swap_address.clone(),
-        details.token1_amount
+        details.token2_amount
     )?;
-    Ok(SwapDetailsResponse {
+    Ok(SwapDetailsPriceResponse {
         name: details.name,
         receiver: details.receiver,
         swap_address: details.swap_address,
-        token1_amount: price.token2_amount,
+        token1_amount: price.token1_amount,
+        token2_amount: details.token2_amount,
         type_code
     })
 }
\ No newline at end of file
